@@ -18,7 +18,7 @@
 #ifndef CORE_DBUS_ASIO_EXECUTOR_H_
 #define CORE_DBUS_ASIO_EXECUTOR_H_
 
-#include <boost/asio/io_service.hpp>
+#include <boost/asio/io_context.hpp>
 
 #include <core/dbus/bus.h>
 #include <core/dbus/executor.h>
@@ -31,7 +31,7 @@ namespace dbus
 namespace asio
 {
 ORG_FREEDESKTOP_DBUS_DLL_PUBLIC Executor::Ptr make_executor(const Bus::Ptr& bus);
-ORG_FREEDESKTOP_DBUS_DLL_PUBLIC Executor::Ptr make_executor(const Bus::Ptr& bus, boost::asio::io_service& io);
+ORG_FREEDESKTOP_DBUS_DLL_PUBLIC Executor::Ptr make_executor(const Bus::Ptr& bus, boost::asio::io_context& io);
 }
 }
 }
